.. _skhep_documentation:

Documentation
=============

This is the main page documenting the *scikit-hep* package, example usage, and the user API.

.. toctree::
    :maxdepth: 2

    api/api.rst
    examples/examples.rst


Indices and tables
------------------

You can also search through the list of modules or the full index:

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
